@@ -3,8 +3,8 @@
 # Author          : Johan Vromans
 # Created On      : Tue Sep 15 15:59:04 1992
 # Last Modified By: Johan Vromans
-# Last Modified On: Thu Jan  2 10:53:08 2020
-# Update Count    : 187
+# Last Modified On: Sat Jan  4 22:28:44 2020
+# Update Count    : 202
 # Status          : Okay
 
 ################ Common stuff ################
@@ -14,7 +14,7 @@ use Getopt::Long 2.1;
 
 my $my_package = "Sciurix";
 my $my_name = "eps2png";
-our $VERSION = 2.8;
+our $VERSION = 2.902;
 
 ################ Program parameters ################
 
@@ -55,6 +55,14 @@ $verbose |= $trace;
 my $eps_file;
 my $err = 0;
 
+my $gv = `gs --version`;
+if ( $gv =~ /^(\d+)\.(\d+)/ ) {
+    $gv = sprintf("%03d%03d", $1, $2);
+}
+else {
+    die("Cannot fetch ghostscript version (was ghostscript installed?)\n")
+}
+
 FILE:
 foreach $eps_file ( @ARGV ) {
 
@@ -172,6 +180,7 @@ foreach $eps_file ( @ARGV ) {
     print STDERR ("Creating $out_file\n") if $verbose;
 
     my $gs0 = "gs -q -dNOPAUSE -r$res -g${width}x$height";
+    $gs0 .= " --permit-file-read=\"$eps_file\"" if $gv > "009027";
     my $gs1 = "-";
     $gs0 .= " -dTextAlphaBits=$antialias -dGraphicsAlphaBits=$antialias"
       if $antialias;
@@ -253,8 +262,9 @@ sub set_out_type {
 }
 
 sub handle_options {
-    my  ($help) = 0;		# handled locally
-    my ($ident) = 0;		# handled locally
+    my $help = 0;		# handled locally
+    my $ident = 0;		# handled locally
+    my $test = 0;		# handled locally
 
     # Process options.
     if ( @ARGV > 0 && $ARGV[0] =~ /^[-+]/ ) {
@@ -284,6 +294,7 @@ sub handle_options {
 			     'resolution=i' => \$res,
 			     'pbm!'	   => \$use_pbm,
 			     'trace'	   => \$trace,
+			     'test'	   => \$test,
 			     'help'	   => \$help,
 			     'debug'	   => \$debug)
 	    && !$help;
@@ -293,7 +304,7 @@ sub handle_options {
     die ("Only one file argument is allowed when -output is used\n")
       if @ARGV > 1 && defined $output;
     die ("At least one input file name must be specified\n")
-      unless @ARGV;
+      unless @ARGV || $test;
     die ("Antialias value must be 0, 1, 2, 4, or 8\n")
       unless "$antialias" =~ /^[01248]$/;
 }
@@ -335,6 +346,9 @@ __END__
 
 eps2png - convert EPS files to PNG, JPG or GIF images
 
+Converts files from EPS format (Encapsulated PostScript) to some
+popular image formats.
+
 =head1 SYNOPSIS
 
     eps2png [ options ] files ...
